@@ -3,7 +3,7 @@
 File:
     ex_omni.py
 
-Desrciption:
+Description:
     Basic example of plotting OMNI data.
 
 """
@@ -13,17 +13,19 @@ import pytplot
 
 
 def ex_omni():
-    # Print the installed version of pyspedas
-    pyspedas.version()
     # Delete any existing pytplot variables
     pytplot.del_data()
+
     # Download OMNI data for 2015-12-31
-    pyspedas.load_data('omni', ['2015-12-31 00:00:00',
-                                '2016-01-01 23:59:59'], '', '', '1min')
+    trange = ['2015-12-31 00:00:00', '2015-12-31 23:59:59']
+    pyspedas.omni.load(trange=trange, datatype='1min')
 
     # Plot
-    pytplot.tplot_options('title', 'OMNI flow_speed 2015-12-31 to 2016-01-01')
+    pytplot.tplot_options('title', 'OMNI flow_speed 2015-12-31')
     pytplot.tplot(['flow_speed'])
 
+    # Return 1 as indication that the example finished without problems.
+    return 1
+
 # Run the example code
 # ex_omni()
